@@ -366,11 +366,23 @@ func selexer(path, contents string) (lexer chroma.Lexer, err error) {
 		return lexers.Analyse(contents), nil
 	}
 
-	if lexer := lexers.Get(cli.Lexer); lexer != nil {
-		return lexer, nil
+	if _, err := os.Stat(cli.Lexer); err == nil {
+		cwd, err := os.Getwd()
+		if err != nil {
+			return nil, err
+		}
+		absPath, err := filepath.Abs(cli.Lexer)
+		if err != nil {
+			return nil, err
+		}
+		path, err := filepath.Rel(cwd, absPath)
+		if err != nil {
+			return nil, err
+		}
+		return chroma.NewXMLLexer(os.DirFS("."), path)
 	}
-	lexerPath, err := filepath.Abs(cli.Lexer)
-	return chroma.NewXMLLexer(os.DirFS("/"), lexerPath)
+
+	return lexers.Get(cli.Lexer), nil
 }
 
 func format(ctx *kong.Context, w io.Writer, style *chroma.Style, it chroma.Iterator) {
@@ -413,9 +425,10 @@ func dumpXMLLexerDefinitions(dir string) error {
 			// fmt.Println(name)
 			_, err = os.Stat(filename)
 			if err == nil {
-				return fmt.Errorf("%s already exists", filename)
+				fmt.Fprintf(os.Stderr, "warning: %s already exists\n", filename)
+				continue
 			}
-			err = ioutil.WriteFile(filename, data, 0600)
+			err = os.WriteFile(filename, data, 0600)
 			if err != nil {
 				return err
 			}
